@@ -33,10 +33,9 @@
 #  define KCRASH_DEPRECATED_NO_EXPORT KCRASH_NO_EXPORT KCRASH_DEPRECATED
 #endif
 
-#if 0 /* DEFINE_NO_DEPRECATED */
-#  ifndef KCRASH_NO_DEPRECATED
-#    define KCRASH_NO_DEPRECATED
-#  endif
+#define DEFINE_NO_DEPRECATED 0
+#if DEFINE_NO_DEPRECATED
+# define KCRASH_NO_DEPRECATED
 #endif
 
-#endif /* KCRASH_EXPORT_H */
+#endif
